@@ -157,7 +157,7 @@ class Reddit:
 
         Additional keyword arguments will be used to initialize the :class:`.Config`
         object. This can be used to specify configuration settings during instantiation
-        of the :class:`.Reddit` instance. For more details please see
+        of the :class:`.Reddit` instance. For more details, please see
         :ref:`configuration`.
 
         Required settings are:
@@ -268,7 +268,7 @@ class Reddit:
         """An instance of :class:`.Inbox`.
 
         Provides the interface to a user's inbox which produces :class:`.Message`,
-        :class:`.Comment`, and :class:`.Submission` instances. For example to iterate
+        :class:`.Comment`, and :class:`.Submission` instances. For example, to iterate
         through comments which mention the authorized user run:
 
         .. code-block:: python
@@ -305,7 +305,7 @@ class Reddit:
         self.redditors = models.Redditors(self, None)
         """An instance of :class:`.Redditors`.
 
-        Provides the interface for Redditor discovery. For example to iterate over the
+        Provides the interface for Redditor discovery. For example, to iterate over the
         newest Redditors, run:
 
         .. code-block:: python
@@ -344,7 +344,7 @@ class Reddit:
         self.subreddits = models.Subreddits(self, None)
         """An instance of :class:`.Subreddits`.
 
-        Provides the interface for :class:`.Subreddit` discovery. For example to iterate
+        Provides the interface for :class:`.Subreddit` discovery. For example, to iterate
         over the set of default subreddits run:
 
         .. code-block:: python
@@ -375,14 +375,14 @@ class Reddit:
             except NameError:
                 pass
             in_async = False
-            if sys.version_info >= (3, 7, 0):
-                try:
+            try:
+                if sys.version_info >= (3, 7, 0):
                     asyncio.get_running_loop()
                     in_async = True
-                except RuntimeError:
-                    pass
-            else:
-                in_async = asyncio.get_event_loop().is_running()
+                else:
+                    in_async = asyncio.get_event_loop().is_running()
+            except Exception:  # Quietly fail if any exception occurs during the check
+                pass
             if in_async:
                 logger.warning(
                     "It appears that you are using PRAW in an asynchronous"
@@ -495,10 +495,9 @@ class Reddit:
         id: Optional[str] = None,  # pylint: disable=redefined-builtin
         url: Optional[str] = None,
     ):
-        """Return a lazy instance of :class:`~.Comment` for ``id``.
+        """Return a lazy instance of :class:`~.Comment`.
 
         :param id: The ID of the comment.
-
         :param url: A permalink pointing to the comment.
 
         .. note::
@@ -822,8 +821,8 @@ class Reddit:
                 # TODO: Remove this exception after 2020-12-31 if no one has
                 # filed a bug against it.
                 raise Exception(
-                    "Unexpected BadRequest without json body. Please file a "
-                    "bug at https://github.com/praw-dev/praw/issues"
+                    "Unexpected BadRequest without json body. Please file a bug at"
+                    " https://github.com/praw-dev/praw/issues."
                 ) from exception
             if set(data) == {"error", "message"}:
                 raise
